# Introduction

Meltano is an open source convention over configuration product for the whole data life cycle, all the way from loading data to analyzing it. To learn more about our progress, check out the [CHANGELOG](https://gitlab.com/meltano/meltano/blob/master/CHANGELOG.md) and our weekly [milestones and roadmap](https://gitlab.com/groups/meltano/-/milestones).

We leverage open source and software development best practices including:

- Version control
- Consistent primitives and naming schema
- Clear and powerful command line interface
- Continuous integration and deployment
- Making it easy to get started with up to date documentation

[![Meltano Diagram](/meltano-diagram.png)](/meltano-diagram.png)

Meltano stands for the steps of the data life cycle:

- Model
- Extract
- Load
- Transform
- Analyze
- Notebook
- Orchestrate

To empower you and your team in this life cycle, Meltano manifests as two tools:

1. command line interface (CLI)
1. web app (GUI)

These two tools enable you and your team to use Meltano in a few different ways:

1. Meltano as a **Project** (CLI + GUI)
    - From data extraction to analysis and visualization with orchestration for automating the process
1. Meltano as a **Framework** (CLI)
    - Helps you create and test extractors, loaders, and transformers
1. Meltano as an **ELT** only (CLI)
    - Runtime for extracting, loading, and transforming data
1. Meltano as a **UI** only (GUI)
    - Interactively query, explore, and visualize data using various charts, reports, and dashboards
